@@ -5,8 +5,9 @@ import oss2
 import json
 import zipfile
 import shutil
+import time
 
-# from . import common
+# import common
 from . import common
 from .lib_repo import LibRepo, LibData
 
@@ -40,9 +41,9 @@ def download_lib(lib_data: LibData, to_path: str):
 
     zip_file = os.path.join(local_path, zip_name)
 
-    logger.info(f'''Downloading {lib_data.name}, version: {lib_data.version},
-             platform: {lib_data.platform}, architecture: {lib_data.arch},
-             config: {lib_data.build}''')
+    logger.info(f'Downloading {lib_data.name}, version: {lib_data.version}, '
+                f'platform: {lib_data.platform}, architecture: {lib_data.arch}, '
+                f'config: {lib_data.build}')
     
     os.makedirs(local_path)
 
@@ -50,7 +51,7 @@ def download_lib(lib_data: LibData, to_path: str):
         download_file(file_key, zip_file)
     except Exception as e:
         logger.exception(f'Failed to download {lib_data.name}. Error: {str(e)}')
-        shutil.rmtree(local_path);
+        shutil.rmtree(local_path)
     else:
         logger.info(f'Unzipping {lib_data.name}.')
         unzip_file(zip_file, local_path)
@@ -116,8 +117,13 @@ def lib_get():
         else:
             print(f'[error] can not find lib from repo. name: {name}, version: {ver}, platform: {platform}, architecture: {arch}, build: {build}')
 
+    logger.info('Begin Download dependent 3rd libraries.')
+
+    start_time = time.time()
     for lib in libs:
         download_lib(lib, args.dest)
+    
+    logger.info(f'End download dependent 3rd libraries. Cost time: {str(time.time() - start_time)} seconds.')
 
 
 if __name__ == '__main__':
